@@ -1,5 +1,5 @@
 test_that("whse_fish_species_cd", {
-  expect_null(chk::check_data(
+  expect_error(chk::check_data(
     fishbc:::whse_fish_species_cd,
     values = list(SPECIES_ID = c(1L, 192L),
                   CODE = "",
@@ -11,7 +11,7 @@ test_that("whse_fish_species_cd", {
                   SPCGRP_CODE = c("", NA)
                   ),
     nrow = 192,
-    key = "SPECIES_ID"))
+    key = "SPECIES_ID"), NA)
 
   chk::check_key(fishbc:::whse_fish_species_cd, "CODE")
   chk::check_key(fishbc:::whse_fish_species_cd, "NAME")
